@@ -11,7 +11,7 @@ use Carp();
 use English qw( -no_match_vars );
 use DirHandle();
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 sub _SIZE_OF_TZ_HEADER                     { return 44 }
 sub _SIZE_OF_TRANSITION_TIME_V1            { return 4 }
@@ -76,6 +76,8 @@ else {
         $_default_zoneinfo_directory = '/usr/lib/zoneinfo';
     }
 }
+my $_zonetab_cache = {};
+my $_tzdata_cache  = {};
 
 sub _DEFAULT_ZONEINFO_DIRECTORY { return $_default_zoneinfo_directory }
 
@@ -107,10 +109,18 @@ sub _timezones {
     my @stat = stat $handle
       or Carp::croak("Failed to stat $path:$EXTENDED_OS_ERROR");
     my $last_modified = $stat[ _STAT_MTIME_IDX() ];
-    if (   ( $self->{_timezone_cache} )
-        && ( $self->{_timezone_cache} == $last_modified ) )
+    if (   ( $self->{_zonetab_last_modified} )
+        && ( $self->{_zonetab_last_modified} == $last_modified ) )
     {
     }
+    elsif (( $_zonetab_cache->{_zonetab_last_modified} )
+        && ( $_zonetab_cache->{_zonetab_last_modified} == $last_modified ) )
+    {
+
+        foreach my $key (qw(_zonetab_last_modified _comments _zones)) {
+            $self->{$key} = $_zonetab_cache->{$key};
+        }
+    }
     else {
         $self->{_zones}    = [];
         $self->{_comments} = {};
@@ -124,7 +134,10 @@ sub _timezones {
         }
         close $handle
           or Carp::croak("Failed to close $path:$EXTENDED_OS_ERROR");
-        $self->{_timezone_cache} = $last_modified;
+        $self->{_zonetab_last_modified} = $last_modified;
+        foreach my $key (qw(_zonetab_last_modified _comments _zones)) {
+            $_zonetab_cache->{$key} = $self->{$key};
+        }
     }
     my @sorted_zones = sort { $a cmp $b } @{ $self->{_zones} };
     return @sorted_zones;
@@ -1404,22 +1417,43 @@ sub _read_tzfile {
     my @stat = stat $handle
       or Carp::croak("Failed to stat $path:$EXTENDED_OS_ERROR");
     my $last_modified = $stat[ _STAT_MTIME_IDX() ];
-    if (   ( $self->{_tzdata}->{$tz}->{mtime} )
-        && ( $self->{_tzdata}->{$tz}->{mtime} == $last_modified ) )
+    if (   ( $self->{_tzdata}->{$tz}->{last_modified} )
+        && ( $self->{_tzdata}->{$tz}->{last_modified} == $last_modified ) )
     {
     }
+    elsif (( $_tzdata_cache->{$tz} )
+        && ( $_tzdata_cache->{$tz}->{last_modified} )
+        && ( $_tzdata_cache->{$tz}->{last_modified} == $last_modified ) )
+    {
+        $self->{_tzdata}->{$tz} = $_tzdata_cache->{$tz};
+    }
     else {
         binmode $handle;
         my $header = $self->_read_header( $handle, $path );
         $self->_read_v1_tzfile( $handle, $path, $header, $tz );
         $self->_read_v2_tzfile( $handle, $path, $header, $tz );
-        $self->{_tzdata}->{$tz}->{mtime} = $last_modified;
+        $self->{_tzdata}->{$tz}->{last_modified} = $last_modified;
+        $_tzdata_cache->{$tz} = $self->{_tzdata}->{$tz};
     }
     close $handle
       or Carp::croak("Failed to close $path:$EXTENDED_OS_ERROR");
     return;
 }
 
+sub reset_cache {
+    my ($self) = @_;
+    if ( ref $self ) {
+        foreach my $key (qw(_tzdata _zonetab_last_modified _comments _zones)) {
+            $self->{$key} = {};
+        }
+    }
+    else {
+        $_tzdata_cache  = {};
+        $_zonetab_cache = {};
+    }
+    return;
+}
+
 1;
 __END__
 =head1 NAME
@@ -1428,7 +1462,7 @@ Time::Zone::Olson - Provides an interface to the Olson timezone database
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
@@ -1504,6 +1538,10 @@ This object method can be used to get the list of transition times for the curre
 
 This object method can be used to get the list of leap seconds for the current timezone.  This method is only intended for testing the results of Time::Zone::Olson.
 
+=head2 reset_cache
+
+This object or class method can be used to reset the cache.  This method is only intended for testing the results of Time::Zone::Olson.  In actual use, cached values are only used if the C<mtime> of the relevant files has not changed.
+
 =head1 DIAGNOSTICS
 
 =over
